@@ -1,5 +1,5 @@
 package Template::Liquid::Block;
-our $VERSION = '1.0.18';
+our $VERSION = '1.0.19';
 require Template::Liquid::Error;
 use base 'Template::Liquid::Document';
 use strict;
@@ -7,17 +7,21 @@ use warnings;
 
 sub new {
     my ($class, $args) = @_;
-    raise Template::Liquid::Error {type    => 'Context',
-                                   type    => 'Context',
-                                   message => 'Missing template argument',
-                                   fatal   => 1
+    raise Template::Liquid::Error {type     => 'Context',
+                                   template => $args->{template},
+                                   message  => 'Missing template argument',
+                                   fatal    => 1
         }
         if !defined $args->{'template'};
-    raise Template::Liquid::Error {type => 'Context',
-                             message => 'Missing parent argument', fatal => 1}
+    raise Template::Liquid::Error {type     => 'Context',
+                                   template => $args->{template},
+                                   message  => 'Missing parent argument',
+                                   fatal    => 1
+        }
         if !defined $args->{'parent'};
     raise Template::Liquid::Error {
-             type    => 'Syntax',
+             template => $args->{template},
+             type     => 'Syntax',
              message => 'else tags are non-conditional: ' . $args->{'markup'},
              fatal   => 1
         }
