@@ -1,5 +1,5 @@
 package Template::Liquid::Tag::Case;
-our $VERSION = '1.0.18';
+our $VERSION = '1.0.19';
 use strict;
 use warnings;
 use base 'Template::Liquid::Tag::If';
@@ -9,23 +9,29 @@ sub import { Template::Liquid::register_tag('case') }
 
 sub new {
     my ($class, $args) = @_;
-    raise Template::Liquid::Error {type    => 'Context',
-                                   message => 'Missing template argument',
-                                   fatal   => 1
+    raise Template::Liquid::Error {type     => 'Context',
+                                   template => $args->{template},
+                                   message  => 'Missing template argument',
+                                   fatal    => 1
         }
         if !defined $args->{'template'};
-    raise Template::Liquid::Error {type => 'Context',
-                             message => 'Missing parent argument', fatal => 1}
+    raise Template::Liquid::Error {type     => 'Context',
+                                   template => $args->{template},
+                                   message  => 'Missing parent argument',
+                                   fatal    => 1
+        }
         if !defined $args->{'parent'};
     raise Template::Liquid::Error {
-                   type    => 'Syntax',
+                   type     => 'Syntax',
+                   template => $args->{template},
                    message => 'Missing argument list in ' . $args->{'markup'},
                    fatal   => 1
         }
         if !defined $args->{'attrs'};
     if ($args->{'attrs'} !~ m[\S$]o) {
         raise Template::Liquid::Error {
-                       type    => 'Syntax',
+                       type     => 'Syntax',
+                       template => $args->{template},
                        message => 'Bad argument list in ' . $args->{'markup'},
                        fatal   => 1
         };
@@ -46,28 +52,31 @@ sub new {
 
 sub push_block {
     my ($s, $args) = @_;
-    raise Template::Liquid::Error {type    => 'Context',
-                                   message => 'Missing template argument',
-                                   fatal   => 1
+    raise Template::Liquid::Error {type     => 'Context',
+                                   template => $s->{template},
+                                   message  => 'Missing template argument',
+                                   fatal    => 1
         }
         if !defined $args->{'template'};
-    raise Template::Liquid::Error {type => 'Context',
-                             message => 'Missing parent argument', fatal => 1}
+    raise Template::Liquid::Error {type     => 'Context',
+                                   template => $s->{template},
+                                   message  => 'Missing parent argument',
+                                   fatal    => 1
+        }
         if !defined $args->{'parent'};
     raise Template::Liquid::Error {
-                   type    => 'Syntax',
+                   type     => 'Syntax',
+                   template => $s->{template},
                    message => 'Missing argument list in ' . $args->{'markup'},
                    fatal   => 1
         }
         if !defined $args->{'attrs'} && $args->{'tag_name'} eq 'when';
     if ($args->{'tag_name'} eq 'when') {
         $args->{'attrs'} = join ' or ',
-            map  { sprintf '%s == %s', $_, $args->{'parent'}{'value'} }
+            map  { sprintf '%s == %s', $args->{'parent'}{'value'}, $_ }
             grep { defined $_ }
             $args->{'attrs'} =~ m[(${Template::Liquid::Utility::Expression})
-                        (?:(?:\s+or\s+|\s*\,\s*)
-                           (${Template::Liquid::Utility::Expression}.*)
-                        )?]ox;
+                        (?:\s+or\s+|\s*\,\s*)?]oxmg;
     }
     my $block =
         Template::Liquid::Block->new({tag_name => $args->{'tag_name'},
